##########
ROMChooser
##########

ROMChooser uses a number of logic steps to decide a best ROM from the list. These are things like region, language,
priority, and various ROM category flags. For more details on how we choose a "best" ROM, see :doc:`1G1R <../1g1r>`.

For more details on the ROMChooser arguments, see the :doc:`config file documentation <../configs/config>`.

API
===

.. autoclass:: romsearch.ROMChooser
    :no-index:
    :members:
    :undoc-members: